@@ -620,7 +620,7 @@ sub binary {
               if $changes
               =~ /(?:#?\s*)(?:\d|n)+ is the bug number of your ITP/i;
         }
-        while ($changes =~ /(closes\s*(?:bug)?\#?\s?\d{6,})[^\w]/ig) {
+        while ($changes =~ /(closes[\s;]*(?:bug)?\#?\s?\d{6,})[^\w]/ig) {
             $self->tag('possible-missing-colon-in-closes', $1) if $1;
         }
         if ($changes =~ m/(TEMP-\d{7}-[0-9a-fA-F]{6})/) {
