@@ -48,7 +48,7 @@ sub spelling_tag_emitter {
     };
 }
 
-sub always {
+sub installable {
     my ($self) = @_;
 
     my $pkg = $self->package;
@@ -239,7 +239,7 @@ sub always {
     if ($synopsis) {
         check_spelling(
             $synopsis,
-            $group->info->spelling_exceptions,
+            $group->spelling_exceptions,
             $self->spelling_tag_emitter(
                 'spelling-error-in-description-synopsis'));
         # Auto-generated dbgsym packages will use the package name in
@@ -256,7 +256,7 @@ sub always {
     if ($description) {
         check_spelling(
             $description,
-            $group->info->spelling_exceptions,
+            $group->spelling_exceptions,
             $self->spelling_tag_emitter('spelling-error-in-description'));
         check_spelling_picky($description,
             $self->spelling_tag_emitter('capitalization-error-in-description')
@@ -273,7 +273,7 @@ sub always {
         my $pmpath = join('/', @mod_path_elements).'.pm';
         my $pm     = $mod_path_elements[-1].'.pm';
 
-        foreach my $filepath ($processable->sorted_index) {
+        foreach my $filepath ($processable->installed->sorted_list) {
             if ($filepath =~ m(\Q$pmpath\E\z|/\Q$pm\E\z)i) {
                 $pm_found = 1;
                 last;
