@@ -157,7 +157,7 @@ my %needs_tag_vals_hash = map { $_ => 1 } @needs_tag_vals;
 
 # -----------------------------------
 
-sub binary {
+sub installable {
     my ($self) = @_;
 
     my $pkg = $self->package;
@@ -178,7 +178,7 @@ sub binary {
         if (my $dir = $processable->installed->lookup("usr/share/$subdir/")) {
             for my $file ($dir->children) {
                 next unless $file->is_file;
-                next unless $file->basename =~ m/\.desktop$/;
+                next unless $file->basename =~ m/\.desktop$/ && !$file->is_dir;
                 if ($file->is_executable) {
                     $self->tag('executable-desktop-file',
                         sprintf('%s %04o',$file, $file->operm));
@@ -203,9 +203,9 @@ sub binary {
         my $fullname = $menufile->name;
 
         # README is a special case
-        next if $menufile->basename eq 'README';
+        next if $menufile->basename eq 'README' && !$menufile->is_dir;
         my $menufile_line ='';
-        my $fd = $menufile->open;
+        open(my $fd, '<', $menufile->unpacked_path);
         # line below is commented out in favour of the while loop
         # do { $_=<IN>; } while defined && (m/^\s* \#/ || m/^\s*$/);
         while (<$fd>) {
@@ -551,7 +551,7 @@ sub verify_icon {
     my $parse = 'XPM header';
     my $line;
 
-    my $fd = $iconfile->open;
+    open(my $fd, '<', $iconfile->unpacked_path);
 
     do { defined($line = <$fd>) or goto parse_error; }
       until ($line =~ /\/\*\s*XPM\s*\*\//);
@@ -583,7 +583,7 @@ sub verify_desktop_file {
     my $pkg = $self->package;
 
     my ($saw_first, $warned_cr, %vals, @pending);
-    my $fd = $file->open;
+    open(my $fd, '<', $file->unpacked_path);
     while (my $line = <$fd>) {
         chomp $line;
         next if ($line =~ m/^\s*\#/ or $line =~ m/^\s*$/);
