@@ -28,7 +28,7 @@ use autodie;
 
 use Lintian::Data;
 use Lintian::Spelling
-  qw(check_spelling check_spelling_picky $known_shells_regex spelling_tag_emitter);
+  qw(check_spelling check_spelling_picky $known_shells_regex);
 use Lintian::Util qw(file_is_encoded_in_non_utf8 strip);
 
 use Moo;
@@ -61,6 +61,13 @@ has menu_file => (is => 'rwp');
 has menumethod_file => (is => 'rwp');
 has documentation => (is => 'rwp', default => 0);
 
+sub spelling_tag_emitter {
+    my ($self, @orig_args) = @_;
+    return sub {
+        return $self->tag(@orig_args, @_);
+    };
+}
+
 sub files {
     my ($self, $file) = @_;
 
@@ -96,7 +103,7 @@ sub files {
             $self->_set_menumethod_file($file->name);
 
             if ($file->is_open_ok) {
-                my $fd = $file->open;
+                open(my $fd, '<', $file->unpacked_path);
                 while (<$fd>) {
                     chomp;
                     if (m,^!include menu.h,o) {
@@ -128,11 +135,11 @@ sub files {
     return;
 }
 
-sub binary {
+sub installable {
     my ($self) = @_;
 
     my $pkg = $self->package;
-    my $info = $self->info;
+    my $processable = $self->processable;
     my $group = $self->group;
 
     my (%all_files, %all_links);
@@ -142,19 +149,21 @@ sub binary {
     my %prerm;
     my %postrm;
 
-    $self->check_script(scalar $info->control_index('preinst'), \%preinst);
-    $self->check_script(scalar $info->control_index('postinst'), \%postinst);
-    $self->check_script(scalar $info->control_index('prerm'), \%prerm);
-    $self->check_script(scalar $info->control_index('postrm'), \%postrm);
+    $self->check_script(scalar $processable->control->lookup('preinst'),
+        \%preinst);
+    $self->check_script(scalar $processable->control->lookup('postinst'),
+        \%postinst);
+    $self->check_script(scalar $processable->control->lookup('prerm'),\%prerm);
+    $self->check_script(scalar $processable->control->lookup('postrm'),
+        \%postrm);
 
     # Populate all_{files,links} from current package and its dependencies
     foreach my $bin ($group->get_binary_processables) {
         next
-          unless $info->name eq $bin->pkg_name
-          or $info->relation('strong')->implies($bin->pkg_name);
-        for my $file ($bin->info->sorted_index) {
-            add_file_link_info($bin->info, $file->name, \%all_files,
-                \%all_links);
+          unless $processable->name eq $bin->name
+          or $processable->relation('strong')->implies($bin->name);
+        for my $file ($bin->installed->sorted_list) {
+            add_file_link_info($bin, $file->name, \%all_files,\%all_links);
         }
     }
 
@@ -189,7 +198,8 @@ sub binary {
 
     # check consistency
     # docbase file?
-    if (my $db_dir = $info->index_resolved_path('usr/share/doc-base/')) {
+    if (my $db_dir
+        = $processable->installed->resolve_path('usr/share/doc-base/')){
         for my $dbpath ($db_dir->children) {
             next if not $dbpath->is_open_ok;
             if ($dbpath->resolve_path->is_executable) {
@@ -249,7 +259,7 @@ sub check_doc_base_file {
     my $group = $self->group;
 
     my $dbfile = $dbpath->basename;
-    my $line = file_is_encoded_in_non_utf8($dbpath->fs_path);
+    my $line = file_is_encoded_in_non_utf8($dbpath->unpacked_path);
     if ($line) {
         $self->tag('doc-base-file-uses-obsolete-national-encoding',
             "$dbfile:$line");
@@ -261,7 +271,7 @@ sub check_doc_base_file {
     my %sawformats;       # global for control file
     $line           = 0;  # global
 
-    my $fd = $dbpath->open;
+    open(my $fd, '<', $dbpath->unpacked_path);
 
     while (<$fd>) {
         chomp;
@@ -430,11 +440,12 @@ sub check_doc_base_field {
     } elsif ($field eq 'title') {
         if (@$vals) {
             my $stag_emitter
-              = spelling_tag_emitter('spelling-error-in-doc-base-title-field',
+              = $self->spelling_tag_emitter(
+                'spelling-error-in-doc-base-title-field',
                 "${dbfile}:${line}");
             check_spelling(
                 join(' ', @$vals),
-                $group->info->spelling_exceptions,
+                $group->spelling_exceptions,
                 $stag_emitter
             );
             check_spelling_picky(join(' ', @$vals), $stag_emitter);
@@ -506,12 +517,12 @@ sub check_doc_base_field {
         # Check spelling.
         if (@$vals) {
             my $stag_emitter
-              = spelling_tag_emitter(
+              = $self->spelling_tag_emitter(
                 'spelling-error-in-doc-base-abstract-field',
                 "${dbfile}:${line}");
             check_spelling(
                 join(' ', @$vals),
-                $group->info->spelling_exceptions,
+                $group->spelling_exceptions,
                 $stag_emitter
             );
             check_spelling_picky(join(' ', @$vals), $stag_emitter);
@@ -550,15 +561,15 @@ sub check_doc_base_file_section {
 # Add file and link to $all_files and $all_links.  Note that both files and
 # links have to include a leading /.
 sub add_file_link_info {
-    my ($info, $file, $all_files, $all_links) = @_;
-    my $link = $info->index($file)->link;
-    my $ishard = $info->index($file)->is_hardlink;
+    my ($processable, $file, $all_files, $all_links) = @_;
+    my $link = $processable->installed->lookup($file)->link;
+    my $ishard = $processable->installed->lookup($file)->is_hardlink;
 
     $file = '/' . $file if (not $file =~ m%^/%); # make file absolute
     $file =~ s%/+%/%g;                           # remove duplicated `/'
     $all_files->{$file} = 1;
 
-    if (defined $link) {
+    if (length $link) {
         $link = './' . $link if $link !~ m,^/,;
         if ($ishard) {
             $link =~ s,^\./,/,;
@@ -638,7 +649,7 @@ sub check_script {
     # control files are regular files and not symlinks, pipes etc.
     return if not $spath or $spath->is_symlink or not $spath->is_open_ok;
 
-    my $fd = $spath->open;
+    open(my $fd, '<', $spath->unpacked_path);
     $interp = <$fd>;
     $interp = '' unless defined $interp;
     if ($interp =~ m,^\#\!\s*/bin/$known_shells_regex,) {
