@@ -22,6 +22,7 @@ package Lintian::udev;
 
 use strict;
 use warnings;
+use autodie qw(open);
 
 use Moo;
 use namespace::clean;
@@ -31,7 +32,7 @@ with 'Lintian::Check';
 # Check /lib/udev/rules.d/, detect use of MODE="0666" and use of
 # GROUP="plugdev" without TAG+="uaccess".
 
-sub binary {
+sub installable {
     my ($self) = @_;
 
     my $pkg = $self->package;
@@ -39,7 +40,7 @@ sub binary {
     my $processable = $self->processable;
     my $group = $self->group;
 
-    my $rules_dir = $processable->index_resolved_path('lib/udev/rules.d/');
+    my $rules_dir = $processable->installed->resolve_path('lib/udev/rules.d/');
     return unless $rules_dir;
     foreach my $file ($rules_dir->children) {
         if (!$file->is_open_ok) {
@@ -101,7 +102,7 @@ sub check_rule {
 sub check_udev_rules {
     my ($self, $file) = @_;
 
-    my $fd = $file->open;
+    open(my $fd, '<', $file->unpacked_path);
     my $linenum = 0;
     my $cont;
     my $retval = 0;
