@@ -31,7 +31,7 @@ use utf8;
 use v5.16;
 
 use Cwd qw(abs_path);
-use Carp qw(verbose);
+use Carp qw(croak verbose);
 use Getopt::Long();
 use List::MoreUtils qw(any none);
 use Path::Tiny;
@@ -46,8 +46,7 @@ use Lintian::Internal::FrontendUtil
 use Lintian::Output::Standard;
 use Lintian::Pool;
 use Lintian::Profile;
-use Lintian::Tags;
-use Lintian::Util qw(internal_error parse_boolean strip safe_qx);
+use Lintian::Util qw(strip safe_qx);
 
 # only in GNOME; need original environment
 my $interactive = -t STDIN && (-t STDOUT || !(-f STDOUT || -c STDOUT));
@@ -89,9 +88,8 @@ my %opt = (                     #hash of some flags from cmd or cfg
 
 my $experimental_output_opts;
 
-my (@CLOSE_AT_END, $TAGS);
+my @CLOSE_AT_END;
 my $OUTPUT = Lintian::Output::Standard->new;
-my @certainties = qw(wild-guess possible certain);
 my (@display_level, %display_source, %suppress_tags);
 my ($action, $checks, $check_tags, $dont_check, $received_signal);
 my @unpack_info;
@@ -356,22 +354,16 @@ sub record_display_level {
     if ($level =~ s/^([<>]=?|=)//) {
         $rel = $1;
     }
-    my ($severity, $certainty) = split('/', $level);
+    my $severity = $level;
     $op = '=' unless defined $op;
     $rel = '=' unless defined $rel;
-    if (not defined $certainty) {
-        if (any { $severity eq $_ } @certainties) {
-            $certainty = $severity;
-            undef $severity;
-        }
-    }
-    push(@display_level, [$op, $rel, $severity, $certainty]);
+    push(@display_level, [$op, $rel, $severity]);
     return;
 }
 
 # Process -I|--display-info flag
 sub display_infotags {
-    push(@display_level, ['+', '>=', 'wishlist']);
+    push(@display_level, ['+', '>=', 'info']);
     return;
 }
 
@@ -381,13 +373,14 @@ sub display_pedantictags {
     return;
 }
 
+sub display_classificationtags {
+    push(@display_level, ['+', '=', 'classification']);
+    return;
+}
+
 # Process --default-display-level flag
 sub default_display_level {
-    push(@display_level,
-        ['=', '>=', 'important'],
-        ['+', '>=', 'normal', 'possible'],
-        ['+', '>=', 'minor', 'certain'],
-    );
+    push(@display_level,['=', '>=', 'warning'],);
     return;
 }
 
@@ -568,6 +561,8 @@ sub _main {
 
 sub main {
 
+    $0 = join(' ', $0, @ARGV);
+
     #turn off file buffering
     STDOUT->autoflush;
     binmode(STDOUT, ':utf8');
@@ -723,19 +718,15 @@ sub main {
     $OUTPUT->v_msg('Using profile ' . $PROFILE->name . '.');
     Lintian::Data->set_vendor($PROFILE);
 
-    $TAGS = Lintian::Tags->new;
-    $TAGS->show_experimental($opt{'display-experimental'});
-    $TAGS->show_overrides($opt{'show-overrides'});
-    $TAGS->sources(keys(%display_source)) if %display_source;
-    $TAGS->profile($PROFILE);
+    $opt{'display-source'} = [keys %display_source];
 
     if ($dont_check || %suppress_tags || $checks || $check_tags) {
-        _update_profile($PROFILE, $TAGS, $dont_check, \%suppress_tags,$checks);
+        _update_profile($PROFILE, $dont_check, \%suppress_tags,$checks);
     }
 
     # Initialize display level settings.
     for my $level (@display_level) {
-        eval { $TAGS->display(@{$level}) };
+        eval { $PROFILE->display(@{$level}) };
         fatal_error($@) if $@;
     }
 
@@ -777,10 +768,11 @@ sub main {
 
     for my $path (@subjects) {
 
+        # in ubuntu, automatic dbgsym packages end with .ddeb
         fatal_error
-"bad package file name $path (neither .deb, .udeb, .changes, .dsc or .buildinfo file)"
+"bad package file name $path (neither .deb, .udeb, .ddeb, .changes, .dsc or .buildinfo file)"
           unless -f $path
-          && $path =~ m/\.(?:u?deb|dsc|changes|buildinfo)$/;
+          && $path =~ m/\.(?:[u|d]?deb|dsc|changes|buildinfo)$/;
 
         my $absolute = Cwd::abs_path($path);
         die "Cannot resolve $path: $!"
@@ -807,7 +799,7 @@ sub main {
 
     $ENV{INIT_ROOT} = $INIT_ROOT;
 
-    $pool->process($action, $PROFILE,$TAGS,\$exit_code, \%opt,
+    $pool->process($action, $PROFILE,\$exit_code, \%opt,
         $STATUS_FD, \@unpack_info, $OUTPUT);
 
     retrigger_signal()
@@ -949,6 +941,38 @@ sub parse_config_file {
     return;
 }
 
+=item parse_boolean (STR)
+
+Attempt to parse STR as a boolean and return its value.
+If STR is not a valid/recognised boolean, the sub will
+invoke croak.
+
+The following values recognised (string checks are not
+case sensitive):
+
+=over 4
+
+=item The integer 0 is considered false
+
+=item Any non-zero integer is considered true
+
+=item "true", "y" and "yes" are considered true
+
+=item "false", "n" and "no" are considered false
+
+=back
+
+=cut
+
+sub parse_boolean {
+    my ($str) = @_;
+    return $str == 0 ? 0 : 1 if $str =~ m/^-?\d++$/o;
+    $str = lc $str;
+    return 1 if $str eq 'true' or $str =~ m/^y(?:es)?$/;
+    return 0 if $str eq 'false' or $str =~ m/^no?$/;
+    croak "\"$str\" is not a valid boolean value";
+}
+
 sub _find_changes {
     my $contents = path('debian/changelog')->slurp;
     my $changelog = Lintian::Inspect::Changelog->new;
@@ -1064,58 +1088,51 @@ sub parse_options {
 }
 
 sub _update_profile {
-    my ($profile, $tags, $sup_check, $sup_tags, $only_check) = @_;
-    my %abbrev = ();
-
-    if ($sup_check || $only_check) {
-        # Build an abbreviation map
-        for my $c ($profile->scripts(1)) {
-            my $cs = $profile->get_script($c, 1);
-            next unless $cs->abbrev;
-            $abbrev{$cs->abbrev} = $cs;
-        }
-    }
+    my ($profile, $sup_check, $sup_tags, $only_check) = @_;
 
     # if tags are listed explicitly (--tags) then show them even if
     # they are pedantic/experimental etc.  However, for --check-part
     # people explicitly have to pass the relevant options.
     if ($checks || $check_tags) {
-        $profile->disable_tags($profile->tags);
+        $profile->disable_tag($_) for $profile->enabled_tags;
         if ($check_tags) {
-            $tags->show_experimental(1);
+            $opt{'display-experimental'} = 1;
             # discard whatever is in @display_level and request
             # everything
             @display_level = ();
             display_infotags();
             display_pedantictags();
-            $profile->enable_tags(split /,/, $check_tags);
+            display_classificationtags();
+            $profile->enable_tag($_) for split(/,/, $check_tags);
         } else {
             for my $c (split /,/, $checks) {
                 if ($c eq 'all') {
                     my @all
-                      = map {$profile->get_script($_, 1) }$profile->scripts(1);
-                    $profile->enable_tags($_->tags)for @all;
+                      = map {$profile->get_checkinfo($_)}
+                      $profile->known_checks;
+                    my @tags = map { $_->tags } @all;
+                    $profile->enable_tag($_) for @tags;
                     next;
                 }
-                my $cs = $profile->get_script($c, 1) || $abbrev{$c};
+                my $cs = $profile->get_checkinfo($c);
                 fatal_error("Unrecognized check script (via -C): $c")
                   unless $cs;
-                $profile->enable_tags($cs->tags);
+                $profile->enable_tag($_) for $cs->tags;
             }
         }
     } elsif ($sup_check) {
         # we are disabling checks
         for my $c (split(/,/, $sup_check)) {
-            my $cs = $profile->get_script($c, 1) || $abbrev{$c};
+            my $cs = $profile->get_checkinfo($c);
             fatal_error("Unrecognized check script (via -X): $c") unless $cs;
-            $profile->disable_tags($cs->tags);
+            $profile->disable_tag($_) for $cs->tags;
         }
     }
 
     # --suppress-tags{,-from-file} can appear alone, but can also be
     # mixed with -C or -X.  Though, ignore it with --tags.
     if (%$sup_tags and not $check_tags) {
-        $profile->disable_tags(keys %$sup_tags);
+        $profile->disable_tag($_) for keys %$sup_tags;
     }
     return;
 }
