@@ -21,6 +21,7 @@ package Lintian::File::Path;
 
 use strict;
 use warnings;
+use autodie qw(open);
 
 use Date::Parse qw(str2time);
 use Carp qw(croak confess);
@@ -33,6 +34,8 @@ use Lintian::Util qw(normalize_pkg_path strip);
 use constant EMPTY => q{};
 use constant SPACE => q{ };
 use constant SLASH => q{/};
+use constant DOT => q{.};
+use constant DOUBLEDOT => q{..};
 use constant DOUBLEQUOTE => q{"};
 use constant BACKSLASH => q{\\};
 
@@ -78,25 +81,6 @@ Lintian::File::Path - Lintian representation of a path entry in a package
 =head1 SYNOPSIS
 
     my ($name, $type, $dir) = ('lintian', 'source', '/path/to/entry');
-    my $info = Lintian::Collect::Source->new($name);
-    my $path = $info->index('bin/ls');
-    if ($path->is_file) {
-       # is file (or hardlink)
-       if ($path->is_hardlink) { }
-       if ($path->is_regular_file) { }
-    } elsif ($path->is_dir) {
-       # is dir
-       if ($path->owner eq 'root') { }
-       if ($path->group eq 'root') { }
-    } elsif ($path->is_symlink) {
-       my $normalized = $path->link_normalized;
-       if (defined($normalized)) {
-           my $more_info = $info->index($normalized);
-           if (defined($more_info)) {
-               # target exists in the package...
-           }
-       }
-    }
 
 =head1 INSTANCE METHODS
 
@@ -234,7 +218,7 @@ sub magic {
 
     my $magic;
 
-    my $fd = $self->open;
+    open(my $fd, '<', $self->unpacked_path);
     die "Could not read $count bytes from ", $self->name
       unless read($fd, $magic, $count) == $count;
     close $fd;
@@ -254,7 +238,7 @@ sub get_interpreter {
     my $magic;
     my $interpreter;
 
-    my $fd = $self->open;
+    open(my $fd, '<', $self->unpacked_path);
     if (read($fd, $magic, 2) && $magic eq '#!' && !eof($fd)) {
         $interpreter = <$fd>;
         strip($interpreter);
@@ -264,6 +248,36 @@ sub get_interpreter {
     return $interpreter;
 }
 
+=item is_script
+
+Returns true if file is a script and false otherwise.
+
+=cut
+
+sub is_script {
+    my ($self) = @_;
+
+    return 1
+      if scalar keys %{$self->script};
+
+    return 0;
+}
+
+=item is_control
+
+Returns true if file is a maintainer script and false otherwise.
+
+=cut
+
+sub is_control {
+    my ($self) = @_;
+
+    return 1
+      if scalar keys %{$self->control};
+
+    return 0;
+}
+
 =item identity
 
 Returns the owner and group of the path, separated by a slash.
@@ -280,23 +294,6 @@ sub identity {
     return $self->owner . SLASH . $self->group;
 }
 
-=item dirname
-
-Returns the "directory" part of the name, similar to dirname(1) or
-File::Basename::dirname.  The dirname will end with a trailing slash
-(except the "root" dir - see below).
-
-NB: Returns the empty string for the "root" dir.
-
-=cut
-
-sub dirname {
-    my ($self) = @_;
-    my $dir = $self->parent_dir;
-    return $dir->name if $dir;
-    return q{};
-}
-
 =item operm
 
 Returns the file permissions of this object in octal (e.g. 0644).
@@ -309,52 +306,54 @@ for symlinks.
 
 sub operm {
     my ($self) = @_;
+
     return $self->path_info & OPERM_MASK;
 }
 
-=item children([RECURSIVE_MODE])
+=item children
 
 Returns a list of children (as Lintian::File::Path objects) of this entry.
 The list and its contents should not be modified.
 
-The optional RECURSIVE_MODE parameter can be used to control if and
-how descendants of this directory is selected.  The following values
-are supported:
-
-=over 4
-
-=item direct
-
-This is the default and only returns direct children of this
-directory.  The entries are sorted by name.
-
-=item breadth-first
-
-Recursive into subdirectories and return the descendants in
-breadth-first order.  Children of a given directory will be sorted by
-name.
-
-=back
+Only returns direct children of this directory.  The entries are sorted by name.
 
 NB: Returns the empty list for non-dir entries.
 
 =cut
 
 sub children {
-    my ($self, $recursive) = @_;
-    return @{$self->sorted_children }
-      if not defined($recursive)
-      or $recursive eq 'direct';
-    croak("Unsupported recursive mode ${recursive}")
-      if $recursive ne 'breadth-first';
-    my @all = @{$self->sorted_children };
-    my @remaining_dirs = grep { $_->is_dir } @all;
-    while (my $dir = shift(@remaining_dirs)) {
-        my @children = $dir->children;
-        push(@all, @children);
-        push(@remaining_dirs, grep { $_->is_dir } @children);
-    }
-    return @all;
+    my ($self) = @_;
+
+    my @names = values %{$self->childnames};
+
+    croak 'No index in ' . $self->name
+      unless defined $self->index;
+
+    return map { $self->index->lookup($_) } @names;
+}
+
+=item descendants
+
+Returns a list of children (as Lintian::File::Path objects) of this entry.
+The list and its contents should not be modified.
+
+Descends recursively into subdirectories and return the descendants in
+breadth-first order.  Children of a given directory will be sorted by
+name.
+
+NB: Returns the empty list for non-dir entries.
+
+=cut
+
+sub descendants {
+    my ($self) = @_;
+
+    my @descendants = $self->children;
+
+    my @directories = grep { $_->is_dir } @descendants;
+    push(@descendants, $_->descendants) for @directories;
+
+    return @descendants;
 }
 
 =item timestamp
@@ -375,35 +374,32 @@ sub timestamp {
 =item child(BASENAME)
 
 Returns the child named BASENAME if it is a child of this directory.
-Otherwise, this method returns C<undef>.  Note if BASENAME has a
-trailing slash, the child entry must be a directory.  If the child
-exist, but is not a directory, C<undef> will be returned instead.
+Otherwise, this method returns C<undef>.
 
-For non-dirs, this method always returns C<undef>.
+Even for directories, BASENAME should not end with a slash.
+
+When invoked on non-dirs, this method always returns C<undef>.
 
 Example:
 
   $dir_entry->child('foo') => $entry OR undef
 
-  $dir_entry->child('foo/') => $dir_entry OR undef
-
 =cut
 
 sub child {
     my ($self, $basename) = @_;
-    my $child_table = $self->child_table;
-    my ($child, $had_trailing_slash);
 
-    # Remove the trailing slash (for dirs)
-    if (substr($basename, -1, 1) eq '/') {
-        $basename = substr($basename, 0, -1);
-        $had_trailing_slash = 1;
-    }
-    return if not $child_table or not exists($child_table->{$basename});
-    $child = $child_table->{$basename};
-    # Only directories are allowed to be fetched with trailing slash.
-    return if $had_trailing_slash and not $child->is_dir;
-    return $child;
+    croak 'Basename is required'
+      unless length $basename;
+
+    my $childname = $self->childnames->{$basename};
+    return
+      unless $childname;
+
+    croak 'No index in ' . $self->name
+      unless defined $self->index;
+
+    return $self->index->lookup($childname);
 }
 
 =item is_symlink
@@ -482,8 +478,8 @@ arguments instead.
 sub link_normalized {
     my ($self) = @_;
 
-    return $self->link_target
-      if length $self->link_target;
+    return $self->normalized
+      if length $self->normalized;
 
     my $name = $self->name;
     my $link = $self->link;
@@ -492,13 +488,14 @@ sub link_normalized {
       unless length $link;
 
     my $dir = $self->dirname;
-    # hardlinks are always relative to the package root
 
-    $dir = '/'
+    # hardlinks are always relative to the package root
+    $dir = SLASH
       if $self->is_hardlink;
 
     my $target = normalize_pkg_path($dir, $link);
-    $self->link_target($target);
+    $self->normalized($target);
+
     return $target;
 }
 
@@ -528,25 +525,7 @@ sub is_readable   { return $_[0]->_any_bit_in_operm(0444); }
 sub is_writable   { return $_[0]->_any_bit_in_operm(0222); }
 sub is_executable { return $_[0]->_any_bit_in_operm(0111); }
 
-=item file_info
-
-Return the data from L<file(1)> if it has been collected.
-
-Note this is only defined for files as Lintian only runs L<file(1)> on
-files.
-
-=cut
-
-sub file_info {
-    my ($self) = @_;
-
-    confess $self->name . ' has not had collected file(1) info'
-      unless defined $self->fileinfo_sub;
-
-    return $self->fileinfo_sub->($self->name);
-}
-
-=item fs_path
+=item unpacked_path
 
 Returns the path to this object on the file system, which must be a
 regular file, a hardlink or a directory.
@@ -576,13 +555,20 @@ defined entry, for which L</is_dir> returns a truth value.
 
 =cut
 
-sub fs_path {
+sub unpacked_path {
     my ($self) = @_;
-    my $path = $self->_collect_path;
+
     $self->_check_access;
-    return $path if $self->resolve_path->is_dir;
-    $self->_check_open($path);
-    return $path;
+
+    croak 'No index in ' . $self->name
+      unless defined $self->index;
+
+    my $basedir = $self->index->basedir;
+
+    croak 'No base directory'
+      unless length $basedir;
+
+    return path($basedir)->child($self->name)->stringify;
 }
 
 =item is_open_ok
@@ -596,33 +582,36 @@ Returns a truth value if the path may be opened.
 
 sub is_open_ok {
     my ($self) = @_;
+
     my $path_info = $self->path_info;
-    return 1 if ($path_info & OPEN_IS_OK) == OPEN_IS_OK;
-    return 0 if $path_info & ACCESS_INFO;
-    eval {
-        my $path = $self->_collect_path;
-        $self->_check_open($path);
-    };
-    return 0 if $@;
+
+    return 1
+      if ($path_info & OPEN_IS_OK) == OPEN_IS_OK;
+
+    return 0
+      if $path_info & ACCESS_INFO;
+
+    eval {$self->_check_open;};
+
+    return 0
+      if $@;
+
     return 1;
 }
 
-sub _collect_path {
-    my ($self) = @_;
-
-    croak 'No base directory'
-      unless length $self->basedir;
-
-    return path($self->basedir)->child($self->name)->stringify;
-}
-
 sub _check_access {
     my ($self) = @_;
+
     my $path_info = $self->path_info;
-    return 1 if ($path_info & FS_PATH_IS_OK) == FS_PATH_IS_OK;
-    return 0 if $path_info & ACCESS_INFO;
+
+    return 1
+      if ($path_info & FS_PATH_IS_OK) == FS_PATH_IS_OK;
+
+    return 0
+      if $path_info & ACCESS_INFO;
+
     my $resolvable = $self->resolve_path;
-    if (not $resolvable) {
+    unless ($resolvable) {
         $self->path_info($self->path_info | UNSAFE_PATH);
         # NB: We are deliberately vague here to avoid suggesting
         # whether $path exists.  In some cases (e.g. lintian.d.o)
@@ -630,80 +619,31 @@ sub _check_access {
         confess('Attempt to access through broken or unsafe symlink:'. ' '
               . $self->name);
     }
+
     $self->path_info($self->path_info | FS_PATH_IS_OK);
+
     return 1;
 }
 
 sub _check_open {
-    my ($self, $path) = @_;
+    my ($self) = @_;
+
     $self->_check_access;
+
     # Symlinks can point to a "non-file" object inside the
     # package root
-    if ($self->is_file or ($self->is_symlink and -f $path)) {
-        $self->path_info($self->path_info | OPEN_IS_OK);
-        return 1;
-    }
     # Leave "_path_access" here as _check_access marks it either as
     # "UNSAFE_PATH" or "FS_PATH_IS_OK"
-    confess("Attempt to open non-file (e.g. dir or pipe): $self");
+
+    confess 'Opening of irregular file not supported: ' . $self->name
+      unless $self->is_file || ($self->is_symlink && -f $self->unpacked_path);
+
+    $self->path_info($self->path_info | OPEN_IS_OK);
+
+    return 1;
 }
 
-sub _do_open {
-    my ($self, $open_sub) = @_;
-    my $path = $self->_collect_path;
-    $self->_check_open($path);
-    return $open_sub->($path);
-}
-
-=item open([LAYER])
-
-Open and return a read handle to the file.  It optionally accepts the
-LAYER argument.  If given it should specify the layer/discipline to
-use when opening the file including the initial colon (e.g. ':raw').
-
-Beyond regular issues with opening a file, this method may fail if:
-
-=over
-
-=item * The object is not a file-like object (e.g. a directory or a named pipe).
-
-=item * If the object is dangling symlink or the path traverses a symlink
-outside the package root.
-
-=back
-
-It is possible to test for these by using L</is_open_ok>.
-
-=cut
-
-sub open {
-    my ($self, $layer) = @_;
-    # Scoped autodie in here to avoid it overwriting our
-    # method "open"
-    $layer //= '';
-    my $opener = sub {
-        use autodie qw(open);
-        open(my $fd, "<${layer}", $_[0]);
-        return $fd;
-    };
-    return $self->_do_open($opener);
-}
-
-=item open_gz
-
-Open a read handle to the file and decompress it as a GZip compressed
-file.  This method may fail for the same reasons as L</open([LAYER])>.
-
-The returned handle may be a pipe from an external process.
-
-=cut
-
-sub open_gz {
-    my ($self) = @_;
-    return $self->_do_open(\&Lintian::Util::open_gz);
-}
-
-=item file_contents
+=item slurp
 
 Return the file contents as a scalar.
 
@@ -711,30 +651,59 @@ This method may fail for the same reasons as L</open([LAYER])>.
 
 =cut
 
-sub file_contents {
+sub slurp {
     my ($self) = @_;
-    return path($self->fs_path)->slurp;
+
+    return
+      unless $self->is_open_ok;
+
+    return path($self->unpacked_path)->slurp;
 }
 
-=item root_dir
+=item follow
 
-Return the root dir entry of this the path entry.
+Return dereferenced link if applicable
 
 =cut
 
-sub root_dir {
-    my ($self) = @_;
-    my $current = $self;
-    while (my $next = $current->parent_dir) {
-        $current = $next;
-    }
-    return $current;
-}
+sub follow {
+    my ($self, $maxlinks) = @_;
 
-sub _set_parent_dir {
-    my ($self, $parent) = @_;
-    $self->parent_dir($parent);
-    return 1;
+    return $self->dereferenced
+      if defined $self->dereferenced;
+
+    # set limit
+    $maxlinks //= 18;
+
+    # catch recursive links
+    return
+      unless $maxlinks > 0;
+
+    # reduce counter
+    $maxlinks--;
+
+    my $reference;
+
+    croak 'No index in ' . $self->name
+      unless defined $self->index;
+
+    if ($self->is_hardlink) {
+        # hard links are resolved against package root
+        $reference = $self->index->lookup;
+
+    } else {
+        # otherwise resolve against the parent
+        $reference = $self->parent_dir;
+    }
+
+    return
+      unless defined $reference;
+
+    # follow link
+    my $dereferenced = $reference->resolve_path($self->link, $maxlinks);
+    $self->dereferenced($dereferenced);
+
+    return $self->dereferenced;
 }
 
 =item resolve_path([PATH])
@@ -783,80 +752,84 @@ Examples:
 =cut
 
 sub resolve_path {
-    my ($self, $path_str) = @_;
-    my $current = $self;
-    my (@queue, %traversed_links, $had_trailing_slash);
+    my ($self, $request, $maxlinks) = @_;
 
-    if (defined($path_str) and ref($path_str) ne q{}) {
-        croak('resolve_path only accepts string arguments');
+    croak 'Can only resolve string arguments'
+      if defined $request && ref($request) ne EMPTY;
+
+    $request //= EMPTY;
+
+    croak 'No index in ' . $self->name
+      unless defined $self->index;
+
+    if (length $self->link) {
+        # follow the link
+        my $dereferenced = $self->follow($maxlinks);
+        return
+          unless defined $dereferenced;
+
+        # and use that to resolve the request
+        return $dereferenced->resolve_path($request, $maxlinks);
     }
 
-    $path_str //= '';
+    my $reference;
 
-    if (not $self->is_dir and not $self->is_symlink) {
-        return $self if $path_str eq '';
-        croak("Path \"$self\" is not a directory or a symlink");
-    }
+    # check for absolute reference; remove slash
+    if ($request =~ s{^/+}{}s) {
 
-    $path_str =~ s{//++}{/}g;
-    $had_trailing_slash = $path_str =~ s{/\z}{};
+        # require anchoring for absolute references
+        return
+          unless $self->index->anchored;
+
+        # get root entry
+        $reference = $self->index->lookup;
+
+    } elsif ($self->is_dir) {
+        # directories are their own starting point
+        $reference = $self;
 
-    if ($path_str =~ s{^/}{} or ($path_str eq q{} and $had_trailing_slash)) {
-        # Find the root entry
-        return unless $self->anchored;
-        $current = $self->root_dir;
-        return $current if $path_str eq q{};
-    }
-    if ($path_str eq q{} or $path_str eq q{.}) {
-        if (not $current->is_symlink) {
-            return $current if ($current->is_dir or not $had_trailing_slash);
-            return;
-        }
     } else {
-        # Add all segments to the queue
-        @queue = split(m{/}, $path_str);
+        # otherwise, use parent directory
+        $reference = $self->parent_dir;
     }
 
-    if ($had_trailing_slash) {
-        # If there is a trailing slash, then the final path segment
-        # must be a directory.
-        push(@queue, q{.});
-    }
+    return
+      unless defined $reference;
 
-    while (1) {
-        my $target;
-        if ($current->is_symlink) {
-            # Stop if we already traversed this link.
-            return if $traversed_links{$current->name}++;
-            my $link_text = $current->link;
-            $link_text =~ s{//++}{/}g;
-            if ($link_text eq q{/} or $link_text =~ s{^/}{}) {
-                return unless $self->anchored;
-                $current = $current->root_dir;
-            } else {
-                $current = $current->parent_dir;
-            }
-            $link_text =~ s{/\z}{};
-            return if $link_text eq q{};
-            unshift(@queue, split(m@/@, $link_text));
+    # read the first path segment
+    if ($request =~ s{^([^/]+/?)}{}s) {
+
+        my $segment = $1;
+
+        # strip trailing slash
+        $segment =~ s{/$}{}s;
+
+        # single dot, or two slashes in a row
+        return $reference->resolve_path($request, $maxlinks)
+          if $segment eq DOT || !length $segment;
+
+        # for double dot, go up a level
+        if ($segment eq DOUBLEDOT) {
+            my $parent = $reference->parent_dir;
+            return
+              unless defined $parent;
+
+            return $parent->resolve_path($request, $maxlinks);
         }
-        last if not @queue;
-        $target = shift(@queue);
 
-        if ($target eq q{..}) {
-            $current = $current->parent_dir;
-            return unless $current;
-        } else {
-            # if there is segment (even a "."), then the current path
-            # must be a directory.
-            return if not $current->is_dir;
-            if ($target ne q{.}) {
-                $current = $current->child($target);
-                return if not $current;
-            }
-        }
+        # look for child otherwise
+        my $child = $reference->child($segment);
+        return
+          unless defined $child;
+
+        return $child->resolve_path($request, $maxlinks);
     }
-    return $current;
+
+    croak "Cannot parse path resolution request: $request"
+      if length $request;
+
+    # nothing else to resolve
+    return $self;
 }
 
 =item name
@@ -873,6 +846,14 @@ case).
 
 NB: Returns the empty string for the "root" dir.
 
+=item dirname
+
+Returns the "directory" part of the name, similar to dirname(1) or
+File::Basename::dirname.  The dirname will end with a trailing slash
+(except the "root" dir - see below).
+
+NB: Returns the empty string for the "root" dir.
+
 =item link
 
 If this is a link (i.e. is_symlink or is_hardlink returns a truth
@@ -886,7 +867,7 @@ where the link target is always relative to the root.
 
 NB: Even for symlinks, a leading "./" will be stripped.
 
-=item link_target
+=item normalized
 
 =item faux
 
@@ -941,22 +922,45 @@ NB: If the gid is not available, 0 will be returned.
 This usually happens if the numerical data is not collected (e.g. in
 source packages)
 
+=item file_info
+
+Return the data from L<file(1)> if it has been collected.
+
+Note this is only defined for files as Lintian only runs L<file(1)> on
+files.
+
+=item java_info
+
+=item script
+
+=item strings
+
+=item objdump
+
+=item control
+
 =item C<basedir>
 
-=item anchored
-
-=item fileinfo_sub
+=item index
 
 =item parent_dir
 
+=item child_table
+
+=item sorted_children
+
 Returns the parent directory entry of this entry as a
 L<Lintian::File::Path>.
 
 NB: Returns C<undef> for the "root" dir.
 
-=item sorted_children
+=item C<childnames>
 
-=item child_table
+=item parent_dir
+
+Return the parent dir entry of this the path entry.
+
+=item dereferenced
 
 =cut
 
@@ -971,8 +975,8 @@ has name => (
         $self->basename($basename);
 
         # allow newline in names; need /s for dot matching (#929729)
-        my ($parentname) = ($name =~ m{^(.+/)?(?:[^/]+/?)$}s);
-        $self->parentname($parentname);
+        my ($dirname) = ($name =~ m{^(.+/)?(?:[^/]+/?)$}s);
+        $self->dirname($dirname);
     },
     default => EMPTY
 );
@@ -982,7 +986,7 @@ has basename => (
     coerce => sub { my ($string) = @_; return $string // EMPTY;},
     default => EMPTY
 );
-has parentname => (
+has dirname => (
     is => 'rw',
     lazy => 1,
     coerce => sub { my ($string) = @_; return $string // EMPTY;},
@@ -994,12 +998,26 @@ has link => (
     coerce => sub { my ($string) = @_; return $string // EMPTY;},
     default => EMPTY
 );
-has link_target => (is => 'rw');
+has normalized => (
+    is => 'rw',
+    coerce => sub { my ($string) = @_; return $string // EMPTY;},
+    default => EMPTY
+);
 has faux => (is => 'rw', default => 0);
 
 has size => (is => 'rw', default => 0);
-has date => (is => 'rw');
-has time => (is => 'rw', default => '00:00');
+has date => (
+    is => 'rw',
+    default => sub {
+        my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = gmtime;
+        return sprintf('%04d-%02d-%02d', $year, $mon, $mday);
+    });
+has time => (
+    is => 'rw',
+    default => sub {
+        my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = gmtime;
+        return sprintf('%02d:%02d:%02d', $hour, $min, $sec);
+    });
 
 has perm => (is => 'rw');
 has path_info => (is => 'rw');
@@ -1025,13 +1043,58 @@ has gid => (
     default => 0
 );
 
-has basedir => (is => 'rw', default => EMPTY);
-has anchored => (is => 'rw', default => 0);
-has fileinfo_sub => (is => 'rw');
+has md5sum => (
+    is => 'rw',
+    coerce => sub { my ($checksum) = @_; return ($checksum // 0); },
+    default => 0
+);
+has file_info => (
+    is => 'rw',
+    coerce => sub { my ($text) = @_; return ($text // EMPTY); },
+    default => EMPTY
+);
+has java_info => (
+    is => 'rw',
+    coerce => sub { my ($hashref) = @_; return ($hashref // {}); },
+    default => sub { {} });
+has script => (
+    is => 'rw',
+    coerce => sub { my ($hashref) = @_; return ($hashref // {}); },
+    default => sub { {} });
+has strings => (
+    is => 'rw',
+    coerce => sub { my ($text) = @_; return ($text // EMPTY); },
+    default => EMPTY
+);
+has objdump => (
+    is => 'rw',
+    coerce => sub { my ($text) = @_; return ($text // EMPTY); },
+    default => EMPTY
+);
+has control => (
+    is => 'rw',
+    coerce => sub { my ($hashref) = @_; return ($hashref // {}); },
+    default => sub { {} });
 
-has parent_dir => (is => 'rw');
-has sorted_children => (is => 'rw', default => sub { [] });
-has child_table => (is => 'rw', default => sub { {} });
+has index => (is => 'rw');
+has childnames => (is => 'rw', default => sub { {} });
+has parent_dir => (
+    is => 'rw',
+    lazy => 1,
+    default => sub {
+        my ($self) = @_;
+
+        # do not return root as its own parent
+        return
+          if $self->name eq EMPTY;
+
+        croak 'No index in ' . $self->name
+          unless defined $self->index;
+
+        # returns root by default
+        return $self->index->lookup($self->dirname);
+    });
+has dereferenced => (is => 'rw');
 
 ### OVERLOADED OPERATORS ###
 
@@ -1089,8 +1152,7 @@ Originally written by Niels Thykier <niels@thykier.net> for Lintian.
 
 =head1 SEE ALSO
 
-lintian(1), Lintian::Collect(3), Lintian::Collect::Binary(3),
-Lintian::Collect::Source(3)
+lintian(1)
 
 =cut
 
